@@ -115,7 +115,7 @@ public class InternalGPS
 
     state = _state;
 
-    if (!safeDestruct.increment()) {
+    if (safeDestruct.increment()) {
       try {
         listener.onSensorStateChanged();
       } finally {
