@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@ Copyright_License {
 #define COMPUTER_SETTINGS_BLACKBOARD_HPP
 
 #include "Computer/Settings.hpp"
-#include "Compiler.h"
+#include "util/Compiler.h"
 
 class ComputerSettingsBlackboard
 {
