@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -38,7 +38,7 @@ void
 CuComputer::Compute(const NMEAInfo &basic, const DerivedInfo &calculated,
                     const ComputerSettings &settings)
 {
-  cu_sonde.SetForecastTemperature(KelvinToCelsius(settings.forecast_temperature));
+  cu_sonde.SetForecastTemperature(settings.forecast_temperature);
 
   cu_sonde.UpdateMeasurements(basic, calculated);
 }
