@@ -40,6 +40,7 @@ Copyright_License {
 #include "Wind/Settings.hpp"
 #include "WaveSettings.hpp"
 #include "RadioFrequency.hpp"
+#include "Cloud/weglide/WeGlideSettings.hpp"
 
 #include <cstdint>
 #include <type_traits>
@@ -227,6 +228,8 @@ struct ComputerSettings {
 
   LoggerSettings logger;
 
+  WeGlideSettings weglide;
+
 #ifdef HAVE_TRACKING
   TrackingSettings tracking;
 #endif
