@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -25,14 +25,13 @@ Copyright_License {
 #define XCSOAR_WIND_SETTINGS_PANEL_HPP
 
 #include "Widget/RowFormWidget.hpp"
-#include "Form/ActionListener.hpp"
 #include "Form/DataField/Listener.hpp"
 #include "Blackboard/BlackboardListener.hpp"
 
 class Button;
 
 class WindSettingsPanel final
-  : public RowFormWidget, public ActionListener,
+  : public RowFormWidget,
     private DataFieldListener, private NullBlackboardListener {
   enum ControlIndex {
     AutoWind,
@@ -66,26 +65,25 @@ public:
    * @param clear_manual_button add a "Clear" button
    */
   WindSettingsPanel(bool edit_manual_wind, bool clear_manual_button,
-                    bool edit_trail_drift);
+                    bool edit_trail_drift) noexcept;
 
-  void SetClearManualButton(Button *_button) {
+  void SetClearManualButton(Button *_button) noexcept {
     clear_manual_window = _button;
   }
 
-  /* virtual methods from Widget */
-  virtual void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
-  virtual bool Save(bool &changed) override;
-  virtual void Show(const PixelRect &rc) override;
-  virtual void Hide() override;
+  void ClearManual() noexcept;
 
-  /* virtual methods from ActionListener */
-  virtual void OnAction(int id) override;
+  /* virtual methods from Widget */
+  void Prepare(ContainerWindow &parent, const PixelRect &rc) noexcept override;
+  bool Save(bool &changed) noexcept override;
+  void Show(const PixelRect &rc) noexcept override;
+  void Hide() noexcept override;
 
 private:
-  void UpdateVector();
+  void UpdateVector() noexcept;
 
   /* methods from DataFieldListener */
-  virtual void OnModified(DataField &df) override;
+  void OnModified(DataField &df) noexcept override;
 
   /* virtual methods from class BlackboardListener */
   virtual void OnCalculatedUpdate(const MoreData &basic,
