@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -23,7 +23,8 @@
 #include "AATIsoline.hpp"
 #include "Points/AATPoint.hpp"
 
-AATIsoline::AATIsoline(const AATPoint& ap, const FlatProjection &projection)
+AATIsoline::AATIsoline(const AATPoint &ap,
+                       const FlatProjection &projection) noexcept
   :ell(ap.GetPrevious()->GetLocationRemaining(),
        ap.GetNext()->GetLocationRemaining(),
        ap.GetTargetLocation(), projection) {}
