@@ -224,7 +224,7 @@ protected:
   virtual void OnDestroy() override;
   virtual void OnResize(PixelSize new_size) override;
 
-  virtual void OnPaintBuffer(Canvas& canvas) override;
+  virtual void OnPaintBuffer(Canvas& canvas) noexcept override;
   virtual void OnPaint(Canvas& canvas) override;
 
   virtual void OnCancelMode() override;
