@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -31,9 +31,9 @@ class ConsoleOperationEnvironment : public QuietOperationEnvironment {
 
 public:
   /* virtual methods from class OperationEnvironment */
-  void SetText(const TCHAR *text) override;
-  void SetProgressRange(unsigned range) override;
-  void SetProgressPosition(unsigned position) override;
+  void SetText(const TCHAR *text) noexcept override;
+  void SetProgressRange(unsigned range) noexcept override;
+  void SetProgressPosition(unsigned position) noexcept override;
 };
 
 #endif
