@@ -96,6 +96,11 @@ const char WatchedWaypointFile[] = "WatchedWPFile"; // pL
 const char LanguageFile[] = "LanguageFile"; // pL
 const char InputFile[] = "InputFile"; // pL
 const char PilotName[] = "PilotName";
+const char WeGlideEnabled[] = "WeGlideEnabled";
+const char WeGlidePilotID[] = "WeGlidePilotID";
+const char WeGlidePilotBirthDate[] = "WeGlidePilotBirthDate";
+const char WeGlideAircraftType[] = "WeGlideAircraftType";
+const char WeGlideAutomaticUpload[] = "WeGlideAutomaticUpload";
 const char CoPilotName[] = "CoPilotName";
 const char AircraftType[] = "AircraftType";
 const char AircraftReg[] = "AircraftReg";
