@@ -24,6 +24,7 @@ Copyright_License {
 #include "Startup.hpp"
 #include "Interface.hpp"
 #include "Components.hpp"
+#include "DataGlobals.hpp"
 #include "Profile/Profile.hpp"
 #include "Profile/Current.hpp"
 #include "Profile/Settings.hpp"
@@ -31,6 +32,7 @@ Copyright_License {
 #include "Simulator.hpp"
 #include "InfoBoxes/InfoBoxManager.hpp"
 #include "Terrain/RasterTerrain.hpp"
+#include "Terrain/AsyncLoader.hpp"
 #include "Weather/Rasp/RaspStore.hpp"
 #include "Input/InputEvents.hpp"
 #include "Input/InputQueue.hpp"
@@ -88,6 +90,8 @@ Copyright_License {
 #include "Task/DefaultTask.hpp"
 #include "Engine/Task/Ordered/OrderedTask.hpp"
 #include "Operation/VerboseOperationEnvironment.hpp"
+#include "Operation/PluggableOperationEnvironment.hpp"
+#include "Widget/ProgressWidget.hpp"
 #include "PageActions.hpp"
 #include "Weather/Features.hpp"
 #include "Weather/NOAAGlue.hpp"
@@ -114,7 +118,6 @@ Copyright_License {
 #ifdef ANDROID
 #include "Android/Main.hpp"
 #include "Android/NativeView.hpp"
-#include "Android/Context.hpp"
 #endif
 
 static TaskManager *task_manager;
@@ -125,7 +128,7 @@ static GlideComputerTaskEvents *task_events;
 static bool
 LoadProfile()
 {
-  if (Profile::GetPath().IsNull() &&
+  if (Profile::GetPath() == nullptr &&
       !dlgStartupShowModal())
     return false;
 
@@ -173,6 +176,50 @@ AfterStartup()
   ForceCalculation();
 }
 
+void
+MainWindow::LoadTerrain() noexcept
+{
+  SetTopWidget(nullptr);
+
+  delete terrain_loader;
+  terrain_loader = nullptr;
+
+  if (const auto path = Profile::GetPath(ProfileKeys::MapFile);
+      path != nullptr) {
+    LogFormat("LoadTerrain");
+    terrain_loader = new AsyncTerrainOverviewLoader();
+
+    terrain_loader_env = std::make_unique<PluggableOperationEnvironment>();
+    auto *progress = new ProgressWidget(*terrain_loader_env,
+                                        _("Loading Terrain File..."));
+    SetTopWidget(progress);
+
+    terrain_loader->Start(file_cache, path, *terrain_loader_env,
+                          terrain_loader_notify);
+  }
+}
+
+void
+MainWindow::OnTerrainLoaded() noexcept
+try {
+  assert(terrain_loader != nullptr);
+
+  std::unique_ptr<AsyncTerrainOverviewLoader> loader{std::exchange(terrain_loader, nullptr)};
+  auto new_terrain = loader->Wait();
+  loader.reset();
+
+  SetTopWidget(nullptr);
+  terrain_loader_env.reset();
+
+  const ScopeSuspendAllThreads suspend;
+
+  DataGlobals::UnsetTerrain();
+  DataGlobals::SetTerrain(std::move(new_terrain));
+  DataGlobals::UpdateHome(false);
+} catch (...) {
+  LogError(std::current_exception(), "LoadTerrain failed");
+}
+
 /**
  * "Boots" up XCSoar
  * @param hInstance Instance handle
@@ -279,18 +326,7 @@ Startup()
 
   main_window->InitialiseConfigured();
 
-  {
-#ifdef ANDROID
-    auto cache_path = context->GetExternalCacheDir(Java::GetEnv());
-    if (cache_path == nullptr)
-      throw std::runtime_error("No Android cache directory");
-
-    // TODO: delete the old cache directory in XCSoarData?
-#else
-    auto cache_path = LocalPath(_T("cache"));
-#endif
-    file_cache = new FileCache(std::move(cache_path));
-  }
+  file_cache = new FileCache(GetCachePath());
 
   ReadLanguageFile();
 
@@ -311,9 +347,7 @@ Startup()
     new ProtectedTaskManager(*task_manager, computer_settings.task);
 
   // Read the terrain file
-  operation.SetText(_("Loading Terrain File..."));
-  LogFormat("OpenTerrain");
-  terrain = RasterTerrain::OpenTerrain(file_cache, operation);
+  main_window->LoadTerrain();
 
   logger = new Logger();
 
@@ -516,11 +550,6 @@ Shutdown()
   // Turn off all displays
   global_running = false;
 
-#ifdef HAVE_TRACKING
-  if (tracking != nullptr)
-    tracking->StopAsync();
-#endif
-
   // Stop logger and save igc file
   operation.SetText(_("Shutdown, saving logs..."));
   if (logger != nullptr)
@@ -613,6 +642,8 @@ Shutdown()
 
   // Clear terrain database
 
+  delete terrain_loader;
+  terrain_loader = nullptr;
   delete terrain;
   terrain = nullptr;
   delete topography;
@@ -646,11 +677,8 @@ Shutdown()
 #endif
 
 #ifdef HAVE_TRACKING
-  if (tracking != nullptr) {
-    tracking->WaitStopped();
-    delete tracking;
-    tracking = nullptr;
-  }
+  delete tracking;
+  tracking = nullptr;
 #endif
 
 #ifdef HAVE_DOWNLOAD_MANAGER
