@@ -41,10 +41,10 @@ Notify::SendNotification() noexcept
   if (pending.exchange(true, std::memory_order_relaxed))
     return;
 
-#if defined(ANDROID) || defined(USE_POLL_EVENT) || defined(ENABLE_SDL)
-  event_queue->Push(Callback, this);
-#else
+#ifdef USE_WINUSER
   SendUser(0);
+#else
+  event_queue->Push(Callback, this);
 #endif
 }
 
@@ -54,7 +54,7 @@ Notify::ClearNotification() noexcept
   if (!pending.exchange(false, std::memory_order_relaxed))
     return;
 
-#if defined(ANDROID) || defined(USE_POLL_EVENT) || defined(ENABLE_SDL)
+#ifndef USE_WINUSER
   event_queue->Purge(Callback, this);
 #endif
 }
