@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -36,7 +36,7 @@ public:
     env.SetProgressRange(30);
     for (unsigned i = 0; i < 30 && !env.IsCancelled(); ++i) {
       env.SetProgressPosition(i);
-      env.Sleep(500);
+      env.Sleep(std::chrono::milliseconds(500));
     }
   }
 };
